import React, { useMemo } from 'react';
import { RawJSONVis, NodeLinkVis, PaohVis, SemanticSubstrates } from '@graphpolaris/shared/lib/vis';
import { useGraphQueryResult, useQuerybuilderGraph, useVisualizationState } from '@graphpolaris/shared/lib/data-access';
import { Visualizations } from '@graphpolaris/shared/lib/data-access/store/visualizationSlice';
import { LoadingSpinner } from '@graphpolaris/shared/lib/components/LoadingSpinner';

export const VisualizationPanel = () => {
  const vis = useVisualizationState();
  const graphQueryResult = useGraphQueryResult();
  const query = useQuerybuilderGraph();

  const visualizationComponent = useMemo(() => {
    switch (vis.activeVisualization) {
      case Visualizations.NodeLink:
        return (
          <div id={Visualizations.NodeLink} className="tabContent w-full h-full">
            <NodeLinkVis />
          </div>
        );
      case Visualizations.RawJSON:
        return (
          <div id={Visualizations.RawJSON} className="tabContent w-full h-full">
            <RawJSONVis />
          </div>
        );
      case Visualizations.Paohvis:
        return (
          <div id={Visualizations.Paohvis} className="tabContent w-full h-full">
            <PaohVis rowHeight={30} hyperedgeColumnWidth={30} gapBetweenRanges={3} />
          </div>
        );
      default:
        return null;
    }
  }, [graphQueryResult]);

  return (
    <div className="vis-panel h-full w-full overflow-y-auto" style={graphQueryResult.nodes.length === 0 ? { overflow: 'hidden' } : {}}>
      <h1>
        <span>Visualization Panel | </span>
        <span className="text-sm">{vis.activeVisualization}</span>
      </h1>
      <div className="h-[calc(100%-2rem)]">
        {graphQueryResult.queryingBackend && (
          <div className="w-full h-full flex flex-col items-center justify-center overflow-hidden">
            <LoadingSpinner>Querying backend...</LoadingSpinner>
          </div>
        )}
        {!graphQueryResult.queryingBackend && graphQueryResult.nodes.length === 0 ? (
          <div className="w-full h-full flex flex-col items-center justify-center">
            <p>No data available to be shown</p>
            {query.nodes.length > 0 ? <p>Query resulted in empty dataset</p> : <p>Query for data to visualize</p>}
          </div>
        ) : (
          <div className="w-full h-full">{visualizationComponent}</div>
        )}
      </div>
    </div>
  );
};
