import FilterAltIcon from '@mui/icons-material/FilterAlt';
import FunctionsIcon from '@mui/icons-material/Functions';
import GridOnIcon from '@mui/icons-material/GridOn';
import NumbersIcon from '@mui/icons-material/Numbers';
import AbcIcon from '@mui/icons-material/Abc';
import { useState } from 'react';
import { AllLogicDescriptions, AllLogicMap, NodeAttribute, QueryGraphNodes, toHandleData } from '../../model';
import { OnConnectStartParams, XYPosition } from 'reactflow';

export const QueryBuilderLogicPillsPanel = (props: {
  className?: string;
  title?: string;
  onClick: (item: AllLogicDescriptions) => void;
  onDrag?: (item: AllLogicDescriptions) => void;
  connection?: {
    params: OnConnectStartParams;
    position: XYPosition;
    node: QueryGraphNodes;
    attribute: NodeAttribute;
  } | null;
}) => {
  let filterType = (props.connection?.params?.handleId ? toHandleData(props.connection.params.handleId).attributeType : null) as string;
  if (!filterType) return <></>;
  else if (filterType === 'string') filterType = 'string';
  else if (filterType === 'int' || filterType === 'float') filterType = 'number';

  const dataOps = [
    {
      title: 'aggregation',
      description: 'Aggregation Functions',
      icon: <GridOnIcon fontSize="small" />,
    },
    {
      title: 'function',
      description: 'Math Functions',
      icon: <FunctionsIcon fontSize="small" />,
    },
    {
      title: 'filter',
      description: 'Filter Functions',
      icon: <FilterAltIcon fontSize="small" />,
    },
  ];
  const dataTypes = [
    {
      title: 'number',
      description: 'Number',
      icon: <NumbersIcon fontSize="small" />,
    },
    {
      title: 'string',
      description: 'Text',
      icon: <AbcIcon fontSize="small" />,
    },
  ].filter((item) => !filterType || item.title === filterType);
  const [selectedOp, setSelectedOp] = useState(-1);
  const [selectedType, setSelectedType] = useState(-1);

  const onDragStart = (event: React.DragEvent, value: AllLogicDescriptions) => {
    console.log('drag start');

    event.dataTransfer.setData('application/reactflow', JSON.stringify({ value }));
    event.dataTransfer.effectAllowed = 'move';
    if (props.onDrag) props.onDrag(value);
  };

  return (
    <div className={props.className + ' card'}>
      {props.title && <h1 className="card-title mb-7">{props.title}</h1>}
      <div className="btn-group w-full justify-center">
        {dataOps.map((item, index) => (
          <div key={item.title} data-tip={item.description} className="tooltip tooltip-top m-0 p-0">
            <button
              className={'btn btn-sm ' + (selectedOp === index ? 'btn-active' : '')}
              onClick={(e) => {
                e.preventDefault();
                index === selectedOp ? setSelectedOp(-1) : setSelectedOp(index);
              }}
            >
              {item.icon}
            </button>
          </div>
        ))}
        <div className="w-2" />
        {dataTypes.map((item, index) => (
          <div key={item.title} data-tip={item.description} className=" tooltip tooltip-top m-0 p-0">
            <button
              className={'btn btn-sm block ' + (selectedType === index ? 'btn-active' : '')}
              onClick={(e) => {
                e.preventDefault();
                index === selectedType ? setSelectedType(-1) : setSelectedType(index);
              }}
            >
              {item.icon}
            </button>
          </div>
        ))}
      </div>
      <div className="overflow-x-hidden h-[75rem] w-full mt-1">
        <ul className="menu p-0 [&_li>*]:rounded-none w-full pb-10 h-full">
          {Object.values(AllLogicMap)
            .filter((item) => !filterType || item.key.toLowerCase().includes(filterType))
            .filter((item) => selectedOp === -1 || item.key.toLowerCase().includes(dataOps?.[selectedOp].title))
            .filter((item) => selectedType === -1 || item.key.toLowerCase().includes(dataTypes?.[selectedType].title))
            .map((item, index) => (
              <li key={item.key + item.description} className="h-fit bg-base-200 ">
                <span
                  data-tip={item.description}
                  className="flex before:w-[10rem] before:text-center tooltip tooltip-bottom text-start "
                  onDragStart={(e) => onDragStart(e, item)}
                  draggable={true}
                  onClick={() => {
                    props.onClick(item);
                  }}
                >
                  {item.icon && (
                    <div className="w-[1rem] rounded-sm justify-center flex">
                      <span>{item.icon}</span>
                    </div>
                  )}
                  <span className="w-full">{item.name}</span>
                  <span className="flex scale-75">
                    {item.key.toLowerCase().includes('filter') && <FilterAltIcon fontSize="small" />}
                    {item.key.toLowerCase().includes('function') && <FunctionsIcon fontSize="small" />}
                    {item.key.toLowerCase().includes('aggregation') && <GridOnIcon fontSize="small" />}
                    {item.key.toLowerCase().includes('number') && <NumbersIcon fontSize="small" />}
                    {item.key.toLowerCase().includes('string') && <AbcIcon fontSize="small" />}
                  </span>
                </span>
              </li>
            ))}
        </ul>
      </div>
    </div>
  );
};
